[![Build Status](https://github.com/herrmannlab/dicomslide/actions/workflows/run_unit_tests.yml/badge.svg)](https://github.com/herrmannlab/dicomslide/actions)
[![PyPi Distribution](https://img.shields.io/pypi/v/dicomslide.svg)](https://pypi.python.org/pypi/dicomslide/)
[![Python Versions](https://img.shields.io/pypi/pyversions/dicomslide.svg)](https://pypi.org/project/dicomslide/)

# dicomslide

A Python library for reading whole slide images and derived information in DICOM format from local files or over network via a unified application programming interface.

## Documentation

Please refer to the online documentation at [dicomslide.readthedocs.io](https://dicomslide.readthedocs.io), which includes installation instructions, a user guide with examples, a developer guide, and complete documentation of the application programming interface of the `dicomslide` package.
